@@ -1,6 +1,7 @@
 
 from .ard import ARDIE
 from .arte import ArteTvIE
+from .auengine import AUEngineIE
 from .bandcamp import BandcampIE
 from .bliptv import BlipTVIE, BlipTVUserIE
 from .breakcom import BreakIE
@@ -138,6 +139,7 @@ def gen_extractors():
         CSpanIE(),
         WimpIE(),
         HotNewHipHopIE(),
+        AUEngineIE(),
         GenericIE()
     ]
 
