@@ -13,6 +13,15 @@ from ..utils import (
 class YahooIE(InfoExtractor):
     """Information extractor for screen.yahoo.com."""
     _VALID_URL = r'http://screen\.yahoo\.com/.*?-(?P<id>\d*?)\.html'
+    _TEST = {
+        u'url': u'http://screen.yahoo.com/julian-smith-travis-legg-watch-214727115.html',
+        u'file': u'214727115.flv',
+        u'md5': u'2e717f169c1be93d84d3794a00d4a325',
+        u'info_dict': {
+            u"title": u"Julian Smith & Travis Legg Watch Julian Smith"
+        },
+        u'skip': u'Requires rtmpdump'
+    }
 
     def _real_extract(self, url):
         mobj = re.match(self._VALID_URL, url)
